from djangomail import send_mail,send_mass_mail
from djangomail.conf import settings
import unittest
class MailTest(unittest.TestCase):
    receivers = ["xxxxx@163.com", "xxxxxx@qq.com"]
    def test_send_mail(self):
        x = send_mail(
            subject="邮件主题",
            message="邮件内容",
            from_email=settings.DEFAULT_FROM_EMAIL,
            recipient_list= self.receivers,
        )
        self.assertTrue(x > 0)

    def test_send_mass_mail(self):
        x =send_mail(
            subject="邮件主题",
            message="邮件内容",
            html_message= '''<h1>邮件内容</h1>
        <h2>副标题</h2>
        <p>段落</p>''',
            from_email=settings.DEFAULT_FROM_EMAIL,
            recipient_list=self.receivers,
        )
        self.assertTrue(x > 0)


    def test_send_html_mail(self):
        message1 = ('Subject here', 'Here is the message', settings.DEFAULT_FROM_EMAIL, self.receivers,)
        message2 = ('Another Subject', 'Here is another message', settings.DEFAULT_FROM_EMAIL, self.receivers,)
        x = send_mass_mail((message1, message2), fail_silently=False)

        self.assertTrue(x > 0)



if __name__ == '__main__':
    unittest.main()



#!/usr/bin/env python


from pathlib import Path
try:
    from setuptools import setup
    from setuptools import find_packages
except ImportError:
    raise ImportError("Could not import \"setuptools\"."
                      "Please install the setuptools package.")


readme = Path("README.md")


# Read the version without importing the package
# (and thus attempting to import packages it depends on that may not be
# installed yet)
version = "0.8"

NAME = 'djangomail'
VERSION = version
DESCRIPTION = 'A stand-alone mail module from django'
KEYWORDS = 'python send email'
AUTHOR = 'somenzz'
AUTHOR_EMAIL = 'somenzz@163.com'
URL = 'https://github.com/somenzz/djangomail'
PACKAGES = find_packages(exclude=['tests', 'tests.*'])

INSTALL_REQUIRES = []
TEST_SUITE = 'tests'
TESTS_REQUIRE = []

CLASSIFIERS = [
    'Development Status :: 3 - Alpha',
    'Intended Audience :: Developers',
    'License :: OSI Approved :: MIT License',
    'Operating System :: OS Independent',
    'Programming Language :: Python',
    'Programming Language :: Python :: 3',
    'Topic :: Software Development',
    'Topic :: Software Development :: Libraries :: Python Modules',
    'Topic :: Utilities',
]

LONG_DESCRIPTION = readme


params = {
    'name':             NAME,
    'version':          VERSION,
    'description':      DESCRIPTION,
    'keywords':         KEYWORDS,
    'author':           AUTHOR,
    'author_email':     AUTHOR_EMAIL,
    'url':              URL,
    'license':          'MIT',
    'packages':         PACKAGES,
    'install_requires': INSTALL_REQUIRES,
    'tests_require':    TESTS_REQUIRE,
    'test_suite':       TEST_SUITE,
    'classifiers':      CLASSIFIERS,
    'long_description': readme.read_text()
}

if __name__ == '__main__':
    setup(**params,long_description_content_type='text/markdown')
